import { Component } from '@angular/core';
import { NavController } from 'ionic-angular';
import { ModalController } from 'ionic-angular';
import { EventosPage } from '../../pages/eventos/eventos';
import { EventosAlumnosPage } from '../../pages/eventos/eventosAlumnos';
import { EventoService } from '../../services/evento';
import { AutService } from '../../services/aut';
import { UsuarioService } from '../../services/usuario';
import firebase from 'firebase';

@Component({
  selector: 'page-calendario',
  templateUrl: 'calendario.html',
  providers: [EventoService]
})
export class CalendarioPage {   
	public eventSource;
    queryMode = 'remote';
    viewTitle;
    isToday: boolean;
    calendar = {
        mode: 'month',        
        currentDate: new Date()
    }; // these are the variable used by the calendar.

    constructor(
        public navCtrl: NavController, 
        public modalCtrl: ModalController,
        private eventService: EventoService,
        private autService: AutService,
        private usrService: UsuarioService
    ) {              
        this.eventSource=[];
    }


    ionViewWillEnter() {    
        this.eventSource =null;
        this.eventSource=[];
        this.loadEvents();     
    }
     
    loadEvents() {        
        this.leerEventosP();
        this.leerEventosA();        
    }
    onViewTitleChanged(title) {
        this.viewTitle = title;
    }
    onEventSelected(event) {
        console.log('Event selected:' + event.startTime + '-' + event.endTime + ',' + event.title);
    }
    changeMode(mode) {
        this.calendar.mode = mode;       
    }
    today() {
        this.calendar.currentDate = new Date();
    }
    onTimeSelected(ev) {
        console.log('Selected time: ' + ev.selectedTime + ', hasEvents: ' +
            (ev.events !== undefined && ev.events.length !== 0) + ', disabled: ' + ev.disabled);
    }
    onCurrentDateChanged(event:Date) {
        var today = new Date();
        today.setHours(0, 0, 0, 0);
        event.setHours(0, 0, 0, 0);
        this.isToday = today.getTime() === event.getTime();
    }

    crearEvento(){
        //En caso de que la app esté en modo docente abrir
        //EventosPage, en caso alumnos EventosAlumnos
        var modoApp = this.usrService.getTipo();

        if (modoApp == 'docente')
        {        
            let modal = this.modalCtrl.create(EventosPage);
            modal.present();
        }
        else
        {
           let modal = this.modalCtrl.create(EventosAlumnosPage);
           modal.present(); 
        }    
    }

   addCalendario(data) 
   {            
        this.eventSource.push({
            startTime:new Date(data.startTime),
            endTime: new Date(data.endTime),
            title:data.title,
            allDay:data.allDay,
            type:data.type });
       
       /* Se vacía el array de eventos del calendario
       para forzar un renderizado de la vista */
       var eventos = this.eventSource.slice();
       this.eventSource = null;
       this.eventSource = eventos;
   }

   leerEventosP(){    
    this.autService.getCurrentUser()
        .then (uid => { 
            this.eventService.leerEventosPersonal(uid);          
            this.eventService.eventosP.subscribe(
                (data) =>{  
                    this.addCalendario(data);   
                }),
                (err)=>{                    
                    console.log(err);}

            });
   }

    leerEventosA(){    
        this.autService.getCurrentUser()
        .then (uid => {  
            this.eventService.leerEventosAsignatura(uid);         
            this.eventService.eventosA.subscribe(
                (data) =>{                      
                    this.addCalendario(data);            
                }),
                (err)=>{                    
                    console.log(err);
                }            
            });
   }
   
    onRangeChanged(ev) {
        console.log('range changed: startTime: ' + ev.startTime + ', endTime: ' + ev.endTime);
    }
    markDisabled = (date:Date) => {
        var current = new Date();
        current.setHours(0, 0, 0);
        return date < current;
    };	
  


}
