import { Component } from '@angular/core';
import { NavController, ViewController } from 'ionic-angular';
import { NgForm } from '@angular/forms';
import { CalendarioPage } from '../../pages/calendario/calendario';
import { Evento} from "../../models/evento";
import { Asignatura} from "../../models/asignatura";
import { EventoService } from '../../services/evento';
import { AsignaturasService } from '../../services/asignaturas';
import { AutService } from '../../services/aut';
import * as moment from 'moment';

@Component({
  selector: 'page-eventos',
  templateUrl: 'eventos.html',
  providers: [EventoService]
})
export class EventosPage {
  evento: Evento;
  erroresForm:string;
  errores:boolean;
  asignaturas: Asignatura[];
  idAsignatura:string;
  asignaturaDisabled:boolean;
  
  constructor(public navCtrl: NavController,
    private viewCtrl: ViewController,
    private eventService: EventoService,
    private asignatService:AsignaturasService,
    private autService: AutService,
   ) 
  {
    this.evento = new Evento();
    this.evento.title = 'Nuevo evento';
    this.erroresForm='';
    this.errores = false;
    this.asignaturas= [];
    this.asignaturaDisabled = true;
    
    this.autService.getCurrentUser()
      .then (uid => {
        asignatService.getAsignaturas(uid)
          .then (lista => {
            var lstAsig = lista.val();
            for(var elem in lstAsig)
            {             
              lstAsig[elem].id = elem;              
              this.asignaturas.push(lstAsig[elem]);             
             }                                                     
          })
          .catch(error => console.log(error)); 

        });

  }

  checkData(form: NgForm) {   
    var fechaInicio = new Date(form.value.startTime);
    var fechaFin = new Date(form.value.endTime);    
    if (fechaFin < fechaInicio) {
      this.errores = true;
      this.erroresForm ='La fecha de fin debe ser posterior a la de inicio';
      console.log("Fecha Fin inferior a fecha inicio");
      return false;
    }
    if(this.evento.type!='personal')
    {
      if(form.value.idAsignatura == '')
      {
        this.errores = true;
        this.erroresForm='Debes indicar una asignatura';        
        return false;
      }  
    }
    return true;
  }

  onCrear( form: NgForm) {
    //Verificar que se cumplen todas las condiciones.
    if(!this.checkData(form))
      return false;

    if(this.evento.type == 'personal')
    {     
      this.eventService.guardarEvento(this.evento)
        .then( data => console.log("Evento guardado "));  
    }  
    else
    {      
      this.eventService.guardarEventoAsignatura(this.evento,form.value.idAsignatura)
        .then(data => console.log("Evento asignatura guardado"));
    }  
    this.viewCtrl.dismiss(); 
  }


  onCancelar()
  {
  	this.viewCtrl.dismiss();
  }

  onChangeStartTime()
  {   
    this.evento.endTime = this.evento.startTime;
  }

  onChangeType()
  {   
    if(this.evento.type == "personal")
      this.asignaturaDisabled=true;
    else
      this.asignaturaDisabled = false;
  }

}
