import { Injectable } from '@angular/core';
import { Evento } from "../models/evento";
import firebase from 'firebase';
import {ReplaySubject} from 'rxjs/ReplaySubject';
import { AutService } from '../services/aut';
import { UsuarioService } from '../services/usuario';


@Injectable()
export class EventoService {	
	private evento: Evento;
	private _eventosPRef:any;
	private _eventosP$: any;
	private _eventosARef:any;
	private _eventosA$: any;
	

	constructor (private autService: AutService,
		private usrService: UsuarioService){
		
		this.evento = new Evento();		
				
	}

	get eventosP()
	{
		return this._eventosP$;
	}
	get eventosA()
	{
		return this._eventosA$;
	}

	handleData(snap) {
		try {			
			this._eventosP$.next(snap.val());
		}
		catch (error) {
			console.log('Error al obtener los eventos del calendario.',error);
		}
	}

	handleDataA(snap) {
		try {			
			this._eventosA$.next(snap.val());
		}
		catch (error) {
			console.log('Error al obtener los eventos del calendario, de tipo Asignatura:',error);
		}
	}
	handleDataPrevA(snap) {
		try {
			snap.ref.child('eventos').on('child_added',this.handleDataA,this);
		}
		catch(error){
			console.log('Error:',error);
		}
	}
	handleDataPrevB(snap) {
		try {				
			if(snap.val()!="")	
			{
					firebase.database().ref('/asignaturas/'+snap.val()+'/eventos')
							.on('child_added',this.handleDataA,this);
			}
		}
		catch(error){
			console.log('Error:',error);
		}
	}


	guardarEvento(evento){
		this.evento = evento;		
		 return firebase.database().ref('/usuarios/' + firebase.auth().currentUser.uid+'/eventos').push(this.evento);			
	}

	guardarEventoAsignatura(evento,idAsignatura){
		this.evento = evento;		
		 return firebase.database().ref('/asignaturas/' + idAsignatura+'/eventos').push(this.evento);			
	}


	leerEventosPersonal(uid) {		
		this._eventosP$ = new ReplaySubject();
		this._eventosPRef = firebase.database().ref('usuarios/'+uid+'/eventos');
				
		this._eventosPRef.on('child_added', this.handleData, this);
		
	}

	/* Leer las tareas y examenes de una determinada asignatura */
	leerTareasExamenes(uid_asignatura) {
		return firebase.database().ref('/asignaturas/'+uid_asignatura+'/eventos/').once('value');

	}

	/* Leer los eventos de tipo Asignatura, pasando el UID 
	del usuario profesor*/
	leerEventosAsignatura(uid) {		
		if(this.usrService.getTipo() == 'docente')
		{			
			this._eventosA$ = new ReplaySubject();
			this._eventosARef = firebase.database().ref('/asignaturas/')			
				.orderByChild("uid_profesor")
				.equalTo(uid)

			this._eventosARef.on('child_added',this.handleDataPrevA, this);
			
		}
		else
		{			
			this._eventosA$ = new ReplaySubject();	
			this._eventosARef= firebase.database().ref('/usuarios/'+uid+'/suscripciones')
			this._eventosARef.on('child_added',this.handleDataPrevB,this)											
		}

			
		
		
	}
}
